#!/usr/bin/env python
from osgeo import gdal
from osgeo import osr
import numpy as np
import os, sys

#  Initialize the Image Size W * H
image_size = (2,3)
# Set pixel size; x = left to right, y = top to bottom
x_res=1
y_res=-1

#  Set the origin
lon = 115
lat = 33
SRID=4326

#  Create Each Channel
r_pixels = np.zeros((image_size[1], image_size[0]), dtype=np.uint8)
g_pixels = np.zeros((image_size[1], image_size[0]), dtype=np.uint8)
b_pixels = np.zeros((image_size[1], image_size[0]), dtype=np.uint8)

#  Set the Pixel Data (3 rows as red, green, and blue)
for x in range(0,image_size[0]):
    for y in range(0,image_size[1]):
        if x < 2 and y == 0:
            r_pixels[y,x] = 255
        elif x < 2 and y == 1:
            g_pixels[y,x] = 255
        else:
            b_pixels[y,x] = 255

# set geotransform
nx = image_size[0]
ny = image_size[1]
geotransform = (lon, x_res, 0, lat, 0, y_res)

# create the 3-band raster file
dst_ds = gdal.GetDriverByName('GTiff').Create('WCS_KISS_A.tif', nx, ny, 3, gdal.GDT_Byte)

dst_ds.SetGeoTransform(geotransform)    # specify coords
srs = osr.SpatialReference()            # establish encoding
srs.ImportFromEPSG(SRID)                # WGS84 lat/long
dst_ds.SetProjection(srs.ExportToWkt()) # export coords to file
dst_ds.GetRasterBand(1).WriteArray(r_pixels)   # write r-band to the raster
dst_ds.GetRasterBand(2).WriteArray(g_pixels)   # write g-band to the raster
dst_ds.GetRasterBand(3).WriteArray(b_pixels)   # write b-band to the raster
dst_ds.FlushCache()                     # write to disk
dst_ds = None